@@ -168,6 +168,8 @@ static const char* acceptable_fields[] = {
     "AptTermLog",
     "DpkgLog",
     "SysLog",
+    /* openjdk-8 */
+    "HotspotError",
 
     NULL,
 };
